spacr.spacr_cellpose — spacr 0.5.0 documentation

# spacr.spacr_cellpose

## Module Contents

spacr.spacr_cellpose.identify_masks_finetune(settings)

spacr.spacr_cellpose.generate_masks_from_imgs(src, model, model_name, batch_size, diameter, cellprob_threshold, flow_threshold, grayscale, save, normalize, channels, percentiles, invert, plot, resize, target_height, target_width, remove_background, background, Signal_to_noise, verbose)

spacr.spacr_cellpose.check_cellpose_models(settings)

spacr.spacr_cellpose.save_results_and_figure(src, fig, results)

spacr.spacr_cellpose.compare_mask(args)

spacr.spacr_cellpose.compare_cellpose_masks(src, verbose=False, processes=None, save=True)